@@ -32,28 +32,19 @@
 from __future__ import annotations
 
 from collections import namedtuple as namedtuple_t
-from typing import (
-    Any,
-    Callable,
-    Dict,
-    Iterable,
-    List,
-    Optional,
-    Sequence,
-    Tuple,
-    Union,
-)
+from typing import Any, Callable, Dict, Iterable, List, Optional, Sequence, Tuple, Union
 
 import matplotlib.pyplot as pl_
 import numpy as np_
 import scipy.interpolate as in_
 import skimage.measure as ms_
 
-import skl_graph.brick.topology_map as bymp
 import skl_graph.brick.elm_id as id_
 import skl_graph.brick.hierarchy as hrcy
+import skl_graph.brick.topology_map as bymp
 from skl_graph.brick.constants import UNTESTED_VALIDITY
 from skl_graph.brick.node import branch_node_t, end_node_t, node_t
+from skl_graph.brick.plot import direction_style_t, edge_styles_h, label_style_t
 
 
 array_t = np_.ndarray
@@ -225,7 +216,7 @@ class edge_t(raw_edge_t):
                 max_distance = 1.0
 
         if max_distance not in self._cache[cache_entry]:
-            output = np_.zeros(self.n_sites, dtype=np_.bool)
+            output = np_.zeros(self.n_sites, dtype=np_.bool_)
             output[0] = True
             output[-1] = True
 
@@ -384,7 +375,7 @@ class _in_progress_edge_t(raw_edge_t):
         """
         sites_as_array = np_.array(self.sites)
         segments = np_.diff(sites_as_array, axis=1)
-        sq_lengths = (segments ** 2).sum(axis=0)
+        sq_lengths = (segments**2).sum(axis=0)
         lengths = np_.sqrt(sq_lengths)
         length = lengths.sum().item()
 
@@ -548,9 +539,11 @@ def Plot(
     transformation: Callable[[array_t], array_t],
     vector_transf: Callable[[array_t], array_t],
     axes: pl_.axes.Axes,
+    edge_styles: edge_styles_h,
+    direction_style: direction_style_t,
+    label_style: label_style_t,
     mode: str = "site",  # "site", "polyline", "curve"
     max_distance: float = 1.0,
-    w_directions: bool = False,
 ) -> None:
     #
     # space_dim = edges[0][2].dim  # Does not work since 'MultiEdgeDataView' object is not subscriptable
@@ -560,7 +553,6 @@ def Plot(
         break
 
     plot_fct = axes.plot if space_dim == 2 else axes.plot3D
-    plot_style = "k." if mode == "site" else "k"
 
     for origin, destination, edge in edges:
         if mode == "curve":
@@ -583,10 +575,19 @@ def Plot(
             )
         sites[0], sites[1] = sites[1], transformation(sites[0])
 
-        line_style = ":" if origin == destination else "-"
-        plot_fct(*sites, plot_style + line_style, linewidth=2, markersize=7)
+        if origin == destination:
+            edge_style = edge_styles[1]
+        else:
+            edge_style = edge_styles[0]
+        plot_style = f"{edge_style.color}." if mode == "site" else edge_style.color
+        plot_fct(
+            *sites,
+            plot_style + edge_style.type,
+            linewidth=edge_style.size,
+            markersize=edge_style.size,
+        )
 
-        if w_directions:
+        if direction_style.show:
             origin_direction = edge.OriginDirection()
             if origin_direction is not None:
                 dir_sites = tuple(
@@ -598,7 +599,14 @@ def Plot(
                     directions[1],
                     vector_transf(directions[0]),
                 )
-                axes.quiver(*dir_sites, *directions, color="b", linewidth=2)
+                axes.quiver(
+                    *dir_sites,
+                    *directions,
+                    color=direction_style.color,
+                    linewidth=direction_style.size,
+                )
+
+        # TODO: plot edge labels
 
 
 def _ReOrderedSites(sites: Tuple[array_t, ...]) -> Tuple[array_t, ...]:
