@@ -37,11 +37,12 @@ import matplotlib.pyplot as pl_
 import numpy as np_
 import scipy.spatial as sp_
 import skimage.measure as ms_
-from mpl_toolkits import mplot3d as m3_
+from mpl_toolkits.mplot3d.art3d import Poly3DCollection as polygons_3d_t
 
-import skl_graph.brick.topology_map as bymp
 import skl_graph.brick.elm_id as id_
+import skl_graph.brick.topology_map as bymp
 from skl_graph.brick.constants import UNTESTED_VALIDITY
+from skl_graph.brick.plot import label_style_t, node_style_h, node_styles_h
 
 
 array_t = np_.ndarray
@@ -134,7 +135,7 @@ class branch_node_t(node_t):
         sites_as_array = np_.array(sites)
         centroid = np_.around(centroid).reshape((-1, 1))
         segments = sites_as_array - centroid
-        medoid_idx = (segments ** 2).sum(axis=0).argmin()
+        medoid_idx = (segments**2).sum(axis=0).argmin()
         # np_.array(): fresh array instead of a view of sites_as_array
         position = np_.array(sites_as_array[:, medoid_idx].squeeze())
 
@@ -198,19 +199,25 @@ def PlotEndNodes(
     nodes: Iterable[Tuple[str, node_t]],
     transformation: Callable[[array_t], array_t],
     axes: pl_.axes.Axes,
+    node_style: node_style_h,
 ) -> None:
-    #
+    """
+    nodes: all the nodes of the graph, so that filtering is needed here
+    """
     positions = np_.array(
         tuple(node.position for _, node in nodes if isinstance(node, end_node_t))
     )
     if positions.size == 0:
         return
 
-    plot_style = "r."
+    plot_style = node_style.color + node_style.type
 
     if positions.shape[1] == 2:
         axes.plot(
-            positions[:, 1], transformation(positions[:, 0]), plot_style, markersize=7
+            positions[:, 1],
+            transformation(positions[:, 0]),
+            plot_style,
+            markersize=node_style.size,
         )
     else:
         axes.plot3D(
@@ -218,19 +225,26 @@ def PlotEndNodes(
             transformation(positions[:, 0]),
             positions[:, 2],
             plot_style,
-            markersize=7,
+            markersize=node_style.size,
         )
 
 
 def Plot2DBranchNodes(
     nodes: Iterable[Tuple[str, node_t]],
+    degrees: Iterable[int],
     transformation: Callable[[array_t], array_t],
     axes: pl_.axes.Axes,
+    node_styles: node_styles_h,
 ) -> None:
-    #
-    positions_0, positions_1 = [], []
-    for _, node in nodes:
+    """
+    nodes: all the nodes of the graph, so that filtering is needed here
+    """
+    positions_0, positions_1, styles, sizes = [], [], [], []
+    for (_, node), degree in zip(nodes, degrees):
+        degree: Tuple[str, int]
         if isinstance(node, branch_node_t):
+            node_style = node_styles.get(degree[1], node_styles[None])
+
             coords_0 = node.sites[1]
             coords_1 = transformation(node.sites[0])
             if coords_0.size > 2:
@@ -238,30 +252,50 @@ def Plot2DBranchNodes(
                     hull = sp_.ConvexHull(np_.transpose((coords_0, coords_1)))
                 except sp_.QhullError:
                     # TODO: check when this happens, in particular flat convex hull
-                    axes.plot(coords_0, coords_1, "g-", linewidth = 2)
+                    axes.plot(
+                        coords_0,
+                        coords_1,
+                        node_style.color + "-",
+                        linewidth=0.3 * node_style.size,
+                    )
                 else:
                     vertices = hull.vertices
-                    axes.fill(coords_0[vertices], coords_1[vertices], "g")
+                    axes.fill(coords_0[vertices], coords_1[vertices], node_style.color)
             elif coords_0.size > 1:
-                axes.plot(coords_0, coords_1, "g-", linewidth=2)
+                axes.plot(
+                    coords_0,
+                    coords_1,
+                    node_style.color + "-",
+                    linewidth=0.3 * node_style.size,
+                )
 
             # Grouping for "better performances"
             positions_0.extend(coords_0)
             positions_1.extend(coords_1)
+            styles.extend(coords_0.size * (node_style.color + node_style.type,))
+            sizes.extend(coords_0.size * (node_style.size,))
 
     if positions_0.__len__() > 0:
-        axes.plot(positions_0, positions_1, "g.", markersize=7)
+        # NOTE: axes.plot does not accept one style and one size per node. Hence the "styles[0]" and "sizes[0]".
+        axes.plot(positions_0, positions_1, styles[0], markersize=sizes[0])
 
 
 def Plot3DBranchNodes(
     nodes: Iterable[Tuple[str, node_t]],
+    degrees: Iterable[int],
     transformation: Callable[[array_t], array_t],
     axes: pl_.axes.Axes,
+    node_styles: node_styles_h,
 ) -> None:
-    #
-    positions_0, positions_1, positions_2 = [], [], []
-    for ___, node in nodes:
+    """
+    nodes: all the nodes of the graph, so that filtering is needed here
+    """
+    positions_0, positions_1, positions_2, styles, sizes = [], [], [], [], []
+    for (_, node), degree in zip(nodes, degrees):
+        degree: Tuple[str, int]
         if isinstance(node, branch_node_t):
+            node_style = node_styles.get(degree[1], node_styles[None])
+
             coords_0 = node.sites[1]
             coords_1 = transformation(node.sites[0])
             coords_2 = node.sites[2]
@@ -274,35 +308,57 @@ def Plot3DBranchNodes(
                         triangle_lst.append(
                             [coords[v_idx, :].tolist() for v_idx in face]
                         )
-                    triangle_lst = m3_.art3d.Poly3DCollection(
-                        triangle_lst, facecolors="g", edgecolors="b", linewidth=1
+                    triangle_lst = polygons_3d_t(
+                        triangle_lst,
+                        facecolors=node_style.color,
+                        edgecolors="b",
+                        linewidth=0.6 * node_style.size,
                     )
                     axes.add_collection3d(triangle_lst)
                 except:
                     # TODO: better space-filling drawing: to be done
-                    axes.plot3D(coords_0, coords_1, coords_2, "g.", markersize=7)
+                    axes.plot3D(
+                        coords_0,
+                        coords_1,
+                        coords_2,
+                        node_style.color + ".",
+                        markersize=node_style.size,
+                    )
             elif coords_0.size > 2:
                 triangle = list(zip(coords_0, coords_1, coords_2))
-                triangle_lst = m3_.art3d.Poly3DCollection([triangle], facecolors="g")
+                triangle_lst = polygons_3d_t([triangle], facecolors=node_style.color)
                 axes.add_collection3d(triangle_lst)
             elif coords_0.size > 1:
-                axes.plot3D(coords_0, coords_1, coords_2, "g-", linewidth=2)
+                axes.plot3D(
+                    coords_0,
+                    coords_1,
+                    coords_2,
+                    node_style.color + "-",
+                    linewidth=0.3 * node_style.size,
+                )
 
             # Grouping for "better performances"
             positions_0.extend(coords_0)
             positions_1.extend(coords_1)
             positions_2.extend(coords_2)
+            styles.extend(coords_0.size * (node_style.color + node_style.type,))
+            sizes.extend(coords_0.size * (node_style.size,))
 
     if positions_0.__len__() > 0:
-        axes.plot3D(positions_0, positions_1, positions_2, "g.", markersize=7)
+        # NOTE: axes.plot3D does not accept one style and one size per node. Hence the "styles[0]" and "sizes[0]".
+        axes.plot3D(
+            positions_0, positions_1, positions_2, styles[0], markersize=sizes[0]
+        )
 
 
 def Plot3DNodeLabels(
     nodes: Iterable[str],
     positions_as_dict: Dict[str, Tuple[int, ...]],
     axes: pl_.axes.Axes,
-    font_size: float,
+    style: label_style_t,
 ) -> None:
     #
     for node in nodes:
-        axes.text(*positions_as_dict[node], node, fontsize=font_size)
+        axes.text(
+            *positions_as_dict[node], node, fontsize=style.size, color=style.color
+        )
