@@ -42,10 +42,10 @@ Simple example usage:
 >>> from skl_graph.skl_map import SKLMapFromObjectMap
 >>> skl_map = SKLMapFromObjectMap(object_map)
 >>> # --- SKL Graph
->>> from skl_graph import skl_graph_t
+>>> from skl_graph.skl_graph import skl_graph_t
 >>> skl_graph = skl_graph_t.FromSKLMap(skl_map)
 >>> # --- End of SKLGraph-based sections
->>> _, axes = pyplot.subplots(nrows=1, ncols=3)
+>>> _, axes = pyplot.subplots(ncols=3)
 >>> axes[0].matshow(object_map, cmap="gray")
 >>> axes[1].matshow(skl_map, cmap="gray")
 >>> skl_graph.Plot(axes=axes[2], should_block=False)
@@ -58,7 +58,6 @@ Simple example usage:
 
 from __future__ import annotations
 
-from enum import Enum as enum_t
 from typing import Callable, ClassVar, Dict, List, Optional, Sequence, Tuple, Union
 
 import matplotlib.pyplot as pl_
@@ -68,18 +67,31 @@ import scipy.ndimage as im_
 import skimage.draw as dw_
 from mpl_toolkits import mplot3d as m3_
 
-import skl_graph.brick.topology_map as bymp
 import skl_graph.brick.edge as dg_
 import skl_graph.brick.node as nd_
+import skl_graph.brick.topology_map as bymp
 from skl_graph.brick.constants import UNTESTED_VALIDITY
+from skl_graph.brick.plot import (
+    axes_t,
+    direction_style_t,
+    direction_style_unstructured_h,
+    edge_style_unstructured_h,
+    edge_styles_h,
+    edge_styles_unstructured_h,
+    figure_t,
+    label_style_t,
+    label_style_unstructured_h,
+    label_styles_h,
+    label_styles_unstructured_h,
+    node_style_unstructured_h,
+    node_styles_h,
+    node_styles_unstructured_h,
+    plot_mode_e,
+    plot_style_t,
+)
 
 
 array_t = np_.ndarray
-axes_t = pl_.Axes
-figure_t = pl_.Figure
-
-
-plot_mode_e = enum_t("plot_mode_e", "Networkx SKL SKL_Polyline SKL_Curve Graphviz")
 
 
 class skl_graph_t(nx_.MultiGraph):
@@ -98,11 +110,15 @@ class skl_graph_t(nx_.MultiGraph):
         "n_b_nodes",
         "has_widths",
         "invalidities",
+        "node_styles",
+        "edge_styles",
+        "direction_style",
+        "label_styles",
     )
 
+    # TODO: use styles instead
+    # TODO: use styles in all functions, not just plotexplicity (partially done for networkx)
     colormap: ClassVar[Dict[int, str]] = {0: "b", 1: "r", 2: "g"}
-    font_size: ClassVar[float] = 6.0
-    width: ClassVar[float] = 2.0
 
     dim: int
     domain_lengths: Tuple[int, ...]
@@ -112,6 +128,10 @@ class skl_graph_t(nx_.MultiGraph):
     n_b_nodes: int
     has_widths: bool
     invalidities: List[str]  # Use brick.constants.UNTESTED_VALIDITY as initial value
+    node_styles: node_styles_h  # One style per degree + one default style
+    edge_styles: edge_styles_h  # One style for "regular" edges, one for self-loops
+    direction_style: direction_style_t
+    label_styles: label_styles_h  # For nodes and edges, in that order
 
     def __init__(self):
         #
@@ -188,6 +208,20 @@ class skl_graph_t(nx_.MultiGraph):
                 instance.n_e_nodes += e_nodes.__len__()
                 instance.n_b_nodes += b_nodes.__len__()
 
+        instance.node_styles = {
+            None: plot_style_t(type=".", size=6, color="g"),
+            1: plot_style_t(type=".", size=6, color="r"),
+        }
+        instance.edge_styles = (
+            plot_style_t(type="-", size=2, color="k"),
+            plot_style_t(type=":", size=2, color="k"),
+        )
+        instance.direction_style = direction_style_t(show=False, size=0, color="k")
+        instance.label_styles = (
+            label_style_t(show=True, size=6.0, color="k"),
+            label_style_t(show=False, size=6.0, color="k"),
+        )
+
         return instance
 
     def _DealsWithSpecialCases(
@@ -433,16 +467,119 @@ class skl_graph_t(nx_.MultiGraph):
 
         return output
 
+    def SetPlotStyles(
+        self,
+        /,
+        *,
+        node: Union[node_style_unstructured_h, node_styles_unstructured_h] = None,
+        edge: edge_style_unstructured_h = None,
+        regular_edge: edge_style_unstructured_h = None,
+        self_loop: edge_style_unstructured_h = None,
+        edges: edge_styles_unstructured_h = None,
+        direction: direction_style_unstructured_h = None,
+        label: label_style_unstructured_h = None,
+        label_node: label_style_unstructured_h = None,
+        label_edge: label_style_unstructured_h = None,
+        labels: label_styles_unstructured_h = None,
+    ) -> None:
+        """
+        edge: common style for both regulars and self-loops
+        edges: styles for regulars and self-loops, in that order
+        label: common style for both nodes and edges
+        labels: styles for nodes and edges, in that order
+        """
+        if node is not None:
+            if isinstance(node, tuple):  # node_style_unstructured_h
+                self.node_styles = {
+                    None: plot_style_t(type=node[0], size=node[1], color=node[2])
+                }
+            else:
+                styles = {
+                    _dgr: plot_style_t(type=_stl[0], size=_stl[1], color=_stl[2])
+                    for _dgr, _stl in node.items()
+                }
+                self.node_styles.update(styles)
+            if None not in self.node_styles:
+                # Should never happen, but just in case...
+                raise ValueError(
+                    f"{self.node_styles}: Node styles without default style. "
+                    f'Expected: style dictionary with a "None" entry.'
+                )
+
+        if edge is not None:
+            style = plot_style_t(type=edge[0], size=edge[1], color=edge[2])
+            styles = (style, style)
+        elif regular_edge is not None:
+            style = plot_style_t(
+                type=regular_edge[0],
+                size=regular_edge[1],
+                color=regular_edge[2],
+            )
+            styles = (style, self.edge_styles[1])
+        elif self_loop is not None:
+            style = plot_style_t(
+                type=self_loop[0],
+                size=self_loop[1],
+                color=self_loop[2],
+            )
+            styles = (self.edge_styles[0], style)
+        elif edges is not None:
+            styles = tuple(
+                plot_style_t(
+                    type=edges[_idx][0],
+                    size=edges[_idx][1],
+                    color=edges[_idx][2],
+                )
+                for _idx in range(2)
+            )
+        else:
+            styles = None
+        if styles is not None:
+            self.edge_styles = styles
+
+        if direction is not None:
+            self.direction_style = direction_style_t(
+                show=direction[0], size=direction[1], color=direction[2]
+            )
+
+        if label is not None:
+            style = label_style_t(show=label[0], size=label[1], color=label[2])
+            styles = (style, style)
+        elif label_node is not None:
+            style = label_style_t(
+                show=label_node[0],
+                size=label_node[1],
+                color=label_node[2],
+            )
+            styles = (style, self.label_styles[1])
+        elif label_edge is not None:
+            style = label_style_t(
+                show=label_edge[0],
+                size=label_edge[1],
+                color=label_edge[2],
+            )
+            styles = (self.label_styles[0], style)
+        elif labels is not None:
+            styles = tuple(
+                label_style_t(
+                    show=labels[_idx][0],
+                    size=labels[_idx][1],
+                    color=labels[_idx][2],
+                )
+                for _idx in range(2)
+            )
+        else:
+            styles = None
+        if styles is not None:
+            self.label_styles = styles
+
     def Plot(
         self,
         figure: pl_.Figure = None,
         axes: pl_.axes.Axes = None,
         mode: plot_mode_e = plot_mode_e.SKL,
         max_distance: float = 1.0,
-        w_directions: bool = False,
         colormap: Dict[int, str] = None,
-        font_size: float = None,
-        width: float = None,
         should_block: bool = True,
         should_return_figure: bool = False,
         should_return_axes: bool = False,
@@ -477,14 +614,9 @@ class skl_graph_t(nx_.MultiGraph):
             for uid, node in self.nodes.data("as_node_t")
         )
 
-        if font_size is None:
-            font_size = self.__class__.font_size
-
         if self.dim == 2:
             if mode is plot_mode_e.Networkx:
-                self._PlotWithNetworkX(
-                    positions_as_dict, axes, colormap, font_size, width
-                )
+                self._PlotWithNetworkX(positions_as_dict, axes, colormap)
             #
             elif mode in (
                 plot_mode_e.SKL,
@@ -496,10 +628,8 @@ class skl_graph_t(nx_.MultiGraph):
                     transformation,
                     vector_transf,
                     axes,
-                    font_size,
                     mode,
                     max_distance,
-                    w_directions,
                 )
             #
             elif mode is plot_mode_e.Graphviz:
@@ -514,10 +644,8 @@ class skl_graph_t(nx_.MultiGraph):
                 transformation,
                 vector_transf,
                 axes,
-                font_size,
                 mode,
                 max_distance,
-                w_directions,
             )
 
         if self.dim == 2:
@@ -542,14 +670,10 @@ class skl_graph_t(nx_.MultiGraph):
         positions_as_dict: Dict[str, Tuple[int, ...]],
         axes: pl_.axes.Axes,
         colormap: Optional[Dict[int, str]],
-        font_size: float,
-        width: Optional[float],
     ) -> None:
         #
         if colormap is None:
             colormap = self.__class__.colormap
-        if width is None:
-            width = self.__class__.width
 
         node_degrees = (elm[1] for elm in self.degree)
         node_colors = tuple(
@@ -561,16 +685,18 @@ class skl_graph_t(nx_.MultiGraph):
             ax=axes,
             pos=positions_as_dict,
             node_color=node_colors,
-            font_size=font_size,
-            width=width,
-        )
-        nx_.draw_networkx_edge_labels(
-            self,
-            ax=axes,
-            pos=positions_as_dict,
-            edge_labels=self._EdgeIDsForPlot(),
-            font_size=int(round(font_size)),
+            with_labels=self.label_styles[0].show,
+            font_size=int(round(self.label_styles[0].size)),
+            width=self.edge_styles[0].size,
         )
+        if self.label_styles[1].show:
+            nx_.draw_networkx_edge_labels(
+                self,
+                ax=axes,
+                pos=positions_as_dict,
+                edge_labels=self._EdgeIDsForPlot(),
+                font_size=int(round(self.label_styles[1].size)),
+            )
 
     def _PlotExplicitly(
         self,
@@ -578,10 +704,8 @@ class skl_graph_t(nx_.MultiGraph):
         transformation: Callable[[array_t], array_t],
         vector_transf: Callable[[array_t], array_t],
         axes: pl_.axes.Axes,
-        font_size: float,
         mode: plot_mode_e,
         max_distance: float,
-        w_directions: bool,
     ) -> None:
         #
         if mode == plot_mode_e.SKL:
@@ -595,20 +719,46 @@ class skl_graph_t(nx_.MultiGraph):
             transformation,
             vector_transf,
             axes,
+            self.edge_styles,
+            self.direction_style,
+            self.label_styles[1],
             mode=mode,
             max_distance=max_distance,
-            w_directions=w_directions,
         )
-        nd_.PlotEndNodes(self.nodes.data("as_node_t"), transformation, axes)
+        # TODO: there is no distinction between end nodes and isolated nodes
+        nd_.PlotEndNodes(
+            self.nodes.data("as_node_t"),
+            transformation,
+            axes,
+            self.node_styles.get(1, self.node_styles[None]),
+        )
 
         if self.dim == 2:
-            nd_.Plot2DBranchNodes(self.nodes.data("as_node_t"), transformation, axes)
-            nx_.draw_networkx_labels(
-                self, ax=axes, pos=positions_as_dict, font_size=int(round(font_size))
+            nd_.Plot2DBranchNodes(
+                self.nodes.data("as_node_t"),
+                self.degree,
+                transformation,
+                axes,
+                self.node_styles,
             )
+            if self.label_styles[0].show:
+                nx_.draw_networkx_labels(
+                    self,
+                    ax=axes,
+                    pos=positions_as_dict,
+                    font_size=int(round(self.label_styles[0].size)),
+                    font_color=self.label_styles[0].color,
+                )
         else:
-            nd_.Plot3DBranchNodes(self.nodes.data("as_node_t"), transformation, axes)
-            nd_.Plot3DNodeLabels(self, positions_as_dict, axes, font_size)
+            nd_.Plot3DBranchNodes(
+                self.nodes.data("as_node_t"),
+                self.degree,
+                transformation,
+                axes,
+                self.node_styles,
+            )
+            if self.label_styles[0].show:
+                nd_.Plot3DNodeLabels(self, positions_as_dict, axes, self.label_styles)
 
     def _PlotWithGraphviz(self, axes: pl_.axes.Axes) -> None:
         #
@@ -623,7 +773,7 @@ class skl_graph_t(nx_.MultiGraph):
                 img_name = tmp_accessor.name
                 graph.layout()
                 graph.draw(img_name, format="png")
-                axes.imshow(io_.imread(img_name))
+                axes.imshow(io_.v3.imread(img_name))
         except Exception as exc:
             axes.text(
                 0,
@@ -665,7 +815,7 @@ class skl_graph_t(nx_.MultiGraph):
 
 def _Ball3D(center: Sequence[int], radius: int, shape: Tuple[int, int, int]) -> array_t:
     #
-    output = np_.zeros(shape, dtype=np_.bool)
+    output = np_.zeros(shape, dtype=np_.bool_)
     # dw_.ellipsoid leaves a one pixel margin around the ellipse, hence [1:-1, 1:-1, 1:-1]
     ellipse = dw_.ellipsoid(radius, radius, radius)[1:-1, 1:-1, 1:-1]
     sp_slices = tuple(
